/*
 * Copyright (c) 1998 The Santa Cruz Operation, Inc.. All Rights Reserved. 
 *                                                                         
 *        THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF THE               
 *                   SANTA CRUZ OPERATION INC.                             
 *                                                                         
 *   The copyright notice above does not evidence any actual or intended   
 *   publication of such source code.                                      
 */

/* $Novell-NWU: $Header: /proj6/ncps/nwu_top/nws/nwu/include/ncpx_app.h,v 1.2 1996/04/05 23:17:58 vtag Exp $ */
/*
 * Copyright 1989 - 1995 Unpublished Work of Novell, Inc.
 * All Rights Reserved.
 * 
 * This work is an unpublished work and contains confidential, proprietary and
 * trade secret information of Novell, Inc. Access to this work is restricted
 * to (I) Novell employees who have a need to know to perform tasks within
 * the scope of their assignments and (II) entities other than Novell who
 * have entered into appropriate agreements.
 * 
 * No part of this work may be used, practiced, performed, copied, distributed,
 * revised, modified, translated, abridged, condensed, expanded, collected,
 * compiled, linked, recast, transformed or adapted without the prior written
 * consent of Novell.  Any use or exploitation of this work without
 * authorization could subject the perpetrator to criminal and civil
 * liability.
 *
 */

/************************************************************************/
/************************************************************************/
/* Support for NCP Extension handlers.
 * This file contains information which is needed by authors of
 * ncpx handler programs.
 */

#ifndef __NWU_NCPX_APP_H_INCLUDED__
#define __NWU_NCPX_APP_H_INCLUDED__

#ident "@(#)ncpx_app.h	1.2"

#ifndef LONG
#include <sys/nwportable.h>
#endif

/************************************************************************/
/* Constants: */

/* Reason why NCPX_EventLoop() returned. */
typedef enum {
	EL_RUNNING = 0,
	EL_EXIT_ERROR,
	EL_EXIT_ALL_HANDLERS_DEREGISTERED,
	EL_EXIT_SERVER_GOING_DOWN,
	EL_EXIT_SIGNAL_SHUTDOWN,
} NCPX_EventLoopState;


/* ConnectionEventHandler() eventTypes: */
#ifdef NOT_USED_IN_NWU
#define CONNECTION_BEING_RESTARTED   0x01101001 
#define CONNECTION_BEING_KILLED      0x02202002 
#endif

#define CONNECTION_BEING_LOGGED_OUT  0x03303003 
#define CONNECTION_BEING_FREED       0x04404004 

/* replyDataLength cookie indicating fragged reply buffer: */
#define REPLY_BUFFER_IS_FRAGGED		0xffffffff


/************************************************************************/
/* Data types and structure definitions: */

/* NCPExtensionHandler() and ReplyBufferManager() client identification: */
typedef struct {
	LONG connection;
	LONG task;
} NCPExtensionClient;


/* These two structures are used to build fragmented reply buffers: */
typedef struct FragElement {
	void	*ptr;
	LONG	size;
} FragElement;

typedef struct NCPExtensionMessageFrag {
	LONG	totalMessageSize;
	LONG	fragCount;
	FragElement	fragList[4];
} NCPExtensionMessageFrag;

/************************************************************************/
/* Function prototypes: */

int	NCPX_EventLoop( NCPX_EventLoopState *exitReason);

int	NWRegisterNCPExtension(const char *NCPExtensionName,
						   BYTE (*NCPExtensionHandler)(NCPExtensionClient *client,
													   void *requestData,
													   LONG requestDataLen,
													   void *replyData,
													   LONG *replyDataLen),
						   void (*ConnectionEventHandler)(LONG connection,
														  LONG eventType),
						   void (*ReplyBufferManager)(NCPExtensionClient *client,
													  void *replyBuffer),
						   BYTE majorVersion,
						   BYTE minorVersion,
						   BYTE revision,
						   void **queryData);

int	NWRegisterNCPExtensionByID(LONG NCPExtensionID,
							   const char *NCPExtensionName,
							   BYTE (*NCPExtensionHandler)(NCPExtensionClient *client,
														   void *requestData,
														   LONG requestDataLen,
														   void *replyData,
														   LONG *replyDataLen),
							   void (*ConnectionEventHandler)(LONG connection,
															  LONG eventType),
							   void (*ReplyBufferManager)(NCPExtensionClient *client,
														  void *replyBuffer),
							   BYTE majorVersion,
							   BYTE minorVersion,
							   BYTE revision,
							   void **queryData);

int	NWDeRegisterNCPExtension( void *queryData);

/* Return the NAME of the object logged-in at the given connection slot.
 * Returned name will be the empty string if the connection isn't logged in,
 * or if there is an error building the name.
 *
 * If the given connectionNumber is invalid, return BAD_STATION_NUMBER.
 * Otherwise, fill in the nameBuf and return ZERO.
 */

int NCPX_GetObjectName( LONG connectionNumber, char *nameBuf, int bufLen);


/* Return TRUE if the connection meets the specified condition, else FALSE. */
int	ConnectionIsLoggedIn( LONG connectionNumber);
int	ConnectionIsAuthenticatedTemporary( LONG connectionNumber);


/* This API is designed to be called ONLY by children processes
 * which are forked off during NCP callback processing.
 * This call will detach from server resources and will close
 * all file descriptors.  In the forked child, this call should
 * be immediately followed by a call to exec().
 */
int NCPX_DetachForkedChildFromServer( void);


/************************************************************************/
#endif /* __NWU_NCPX_APP_H_INCLUDED__ */
/************************************************************************/
/************************************************************************/
